export function setupReport(conversationID) {
    const reportProblem = document.getElementById('report-problem');
    const reportPopup = document.getElementById('report-popup');
    const cancelReport = document.getElementById('cancel-report');
    const sendReport = document.getElementById('send-report');
    const REPORT_URL = 'https://chat.upb.ro/api/report/';

    reportProblem.addEventListener('click', function() {
        reportPopup.classList.remove('hidden');
    });

    cancelReport.addEventListener('click', function() {
        reportPopup.classList.add('hidden');
        document.getElementById('report-description').value = '';
    });

    sendReport.addEventListener('click', async function() {
        const reportDescription = document.getElementById('report-description').value.trim();
        if (!reportDescription) {
            alert('Vă rugăm să descrieți problema.');
            return;
        }

        // Disable send button to prevent multiple submissions
        sendReport.disabled = true;
        sendReport.textContent = 'Se trimite...';

        try {
            // Prepare the request payload with message history and report description
            const requestOptions = {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json'
                },
                body: JSON.stringify({
                    conversation_id: conversationID,
                    report: reportDescription,
                    reportType: 'problem'
                })
            };

            const response = await fetch(REPORT_URL, requestOptions);

            alert('Raportul a fost trimis. Vă mulțumim pentru feedback!');
            reportPopup.classList.add('hidden');
            document.getElementById('report-description').value = '';

        } catch (error) {
            console.error('Error sending report:', error);
            alert('A apărut o eroare la trimiterea raportului. Vă rugăm să încercați din nou.');
        } finally {
            sendReport.disabled = false;
            sendReport.textContent = 'Trimite';
        }
    });

    // Close report popup when clicking outside of it
    reportPopup.addEventListener('click', function(e) {
        if (e.target === reportPopup) {
            reportPopup.classList.add('hidden');
            document.getElementById('report-description').value = '';
        }
    });
}
