import { messageHistory, recordMessage } from "./messages.js";
import { reply } from "./api.js";


function handleChoices(conversationID, savedLocation, savedSubject) {
    const chatInput = document.getElementById('chat-input');
    const chatInputContainer = document.getElementById('chat-input-container');
    const chatMessages = document.getElementById('chat-messages');

    const locationSelector = document.getElementById('location-selector');
    locationSelector.classList.add('hidden');
    chatMessages.classList.remove('hidden');
    chatInputContainer.classList.remove('hidden');

    setTimeout(() => {
        let messageText = `Bună 👋! Ați selectat ${savedLocation}, subiect: ${savedSubject}. Cum vă pot ajuta cu informații despre admitere?\n\nRăspunsurile sunt orientative și pot conține erori; vă rugăm să verificați toate răspunsurile cu sursele furnizate.  \nConținutul conversațiilor este păstrat pentru îmbunătățirea serviciilor; nu trimiteți date personale.  \nPlatforma oficială de admitere se găsește la adresa [admitere.pub.ro](https://admitere.pub.ro).  \nPentru orice întrebare suplimentară, puteți contacta [admitere.anticipata@upb.ro](mailto:admitere.anticipata@upb.ro).  \nPentru contact telefonic ne puteți găsi [aici](https://admitere.pub.ro/docs/Date%20contact%20CLA_2025.pdf?v=24.03.29).`;
        // XXX Bump this number whenever you change the welcome message!
        let welcomeMessageID = "welcome-message-1";
        reply(conversationID, welcomeMessageID, messageText, true);
    }, 300);

    chatInput.focus();
}

function isSoftReload(conversationID) {
    const softReload = sessionStorage.getItem('softReload') === 'true';

    sessionStorage.removeItem('softReload');
    if (!softReload) {
        sessionStorage.removeItem('selectedLocation');
        sessionStorage.removeItem('selectedSubject');
    }

    if (!softReload)
        return false;

    const savedLocation = sessionStorage.getItem('selectedLocation');
    const savedSubject = sessionStorage.getItem('selectedSubject');
    if (savedLocation && savedSubject) {
        handleChoices(conversationID, savedLocation, savedSubject);
        return true;
    } else {
        // We should never get here, but it's not so bad: we just need to ask again.
        return false;
    }
}


export function setupSelections(conversationID) {
    let selectedLocation = '';

    if (isSoftReload(conversationID)) {
        return;
    }

    const subjectSelector = document.createElement('div');
    subjectSelector.id = 'subject-selector';
    subjectSelector.className = 'flex-1 p-6 overflow-y-auto flex flex-col items-center justify-center hidden';
    subjectSelector.innerHTML = `
        <h3 class="text-lg font-medium text-gray-800 mb-4">Vă rugăm să selectați subiectul:</h3>
        <div class="flex flex-col space-y-4 w-full max-w-xs">
        <button id="licenta-btn" class="location-btn bg-gray-800 hover:bg-gray-700 text-white py-3 px-6 rounded-lg text-center">
        Admitere Licență 2025
        </button>
        </div>
        `;

    const locationSelector = document.getElementById('location-selector');
    locationSelector.parentNode.insertBefore(subjectSelector,
        locationSelector.nextSibling);

    function selectLocation(location) {
        selectedLocation = location;
        sessionStorage.setItem('selectedLocation', location);

        locationSelector.classList.add('hidden');
        subjectSelector.classList.remove('hidden');

        document.getElementById('licenta-btn').addEventListener('click', function() {
            selectSubject('Admitere Licență 2025');
        });
    }

    function selectSubject(subject) {
        const selectedSubject = subject;

        sessionStorage.setItem('selectedSubject', subject); // Save selection

        subjectSelector.classList.add('hidden');
        handleChoices(conversationID, selectedLocation, selectedSubject);
    }

    document.getElementById('bucuresti-btn').addEventListener('click', function() {
        selectLocation('Centrul Universitar București');
    });

    document.getElementById('pitesti-btn').addEventListener('click', function() {
        selectLocation('Centrul Universitar Pitești');
    });
}
